# youtube-ti
The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.0.1
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://google.com](https://google.com)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import youtube_ti
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import youtube_ti
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import youtube_ti
from youtube_ti.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://youtube.googleapis.com
# See configuration.py for a list of all supported configuration parameters.
configuration = youtube_ti.Configuration(
    host = "https://youtube.googleapis.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with youtube_ti.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = youtube_ti.AbuseReportsApi(api_client)
    part = ['part_example'] # List[str] | The *part* parameter serves two purposes in this operation. It identifies the properties that the write operation will set as well as the properties that the API response will include.
    oauth_token = 'oauth_token_example' # str | OAuth 2.0 token for the current user. (optional)
    key = 'key_example' # str | API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. (optional)
    upload_type = 'upload_type_example' # str | Legacy upload protocol for media (e.g. \"media\", \"multipart\"). (optional)
    quota_user = 'quota_user_example' # str | Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. (optional)
    upload_protocol = 'upload_protocol_example' # str | Upload protocol for media (e.g. \"raw\", \"multipart\"). (optional)
    param_callback = 'param_callback_example' # str | JSONP (optional)
    fields = 'fields_example' # str | Selector specifying which fields to include in a partial response. (optional)
    xgafv = 'xgafv_example' # str | V1 error format. (optional)
    pretty_print = True # bool | Returns response with indentations and line breaks. (optional) (default to True)
    access_token = 'access_token_example' # str | OAuth access token. (optional)
    alt = json # str | Data format for response. (optional) (default to json)
    abuse_report = youtube_ti.AbuseReport() # AbuseReport |  (optional)

    try:
        api_response = api_instance.youtube_abuse_reports_insert(part, oauth_token=oauth_token, key=key, upload_type=upload_type, quota_user=quota_user, upload_protocol=upload_protocol, param_callback=param_callback, fields=fields, xgafv=xgafv, pretty_print=pretty_print, access_token=access_token, alt=alt, abuse_report=abuse_report)
        print("The response of AbuseReportsApi->youtube_abuse_reports_insert:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AbuseReportsApi->youtube_abuse_reports_insert: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://youtube.googleapis.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AbuseReportsApi* | [**youtube_abuse_reports_insert**](docs/AbuseReportsApi.md#youtube_abuse_reports_insert) | **POST** /youtube/v3/abuseReports | 
*ActivitiesApi* | [**youtube_activities_list**](docs/ActivitiesApi.md#youtube_activities_list) | **GET** /youtube/v3/activities | 
*CaptionsApi* | [**youtube_captions_delete**](docs/CaptionsApi.md#youtube_captions_delete) | **DELETE** /youtube/v3/captions | 
*CaptionsApi* | [**youtube_captions_download**](docs/CaptionsApi.md#youtube_captions_download) | **GET** /youtube/v3/captions/{id} | 
*CaptionsApi* | [**youtube_captions_insert**](docs/CaptionsApi.md#youtube_captions_insert) | **POST** /youtube/v3/captions | 
*CaptionsApi* | [**youtube_captions_list**](docs/CaptionsApi.md#youtube_captions_list) | **GET** /youtube/v3/captions | 
*CaptionsApi* | [**youtube_captions_update**](docs/CaptionsApi.md#youtube_captions_update) | **PUT** /youtube/v3/captions | 
*ChannelBannersApi* | [**youtube_channel_banners_insert**](docs/ChannelBannersApi.md#youtube_channel_banners_insert) | **POST** /youtube/v3/channelBanners/insert | 
*ChannelSectionsApi* | [**youtube_channel_sections_delete**](docs/ChannelSectionsApi.md#youtube_channel_sections_delete) | **DELETE** /youtube/v3/channelSections | 
*ChannelSectionsApi* | [**youtube_channel_sections_insert**](docs/ChannelSectionsApi.md#youtube_channel_sections_insert) | **POST** /youtube/v3/channelSections | 
*ChannelSectionsApi* | [**youtube_channel_sections_list**](docs/ChannelSectionsApi.md#youtube_channel_sections_list) | **GET** /youtube/v3/channelSections | 
*ChannelSectionsApi* | [**youtube_channel_sections_update**](docs/ChannelSectionsApi.md#youtube_channel_sections_update) | **PUT** /youtube/v3/channelSections | 
*ChannelsApi* | [**youtube_channels_list**](docs/ChannelsApi.md#youtube_channels_list) | **GET** /youtube/v3/channels | 
*ChannelsApi* | [**youtube_channels_update**](docs/ChannelsApi.md#youtube_channels_update) | **PUT** /youtube/v3/channels | 
*CommentThreadsApi* | [**youtube_comment_threads_insert**](docs/CommentThreadsApi.md#youtube_comment_threads_insert) | **POST** /youtube/v3/commentThreads | 
*CommentThreadsApi* | [**youtube_comment_threads_list**](docs/CommentThreadsApi.md#youtube_comment_threads_list) | **GET** /youtube/v3/commentThreads | 
*CommentsApi* | [**youtube_comments_delete**](docs/CommentsApi.md#youtube_comments_delete) | **DELETE** /youtube/v3/comments | 
*CommentsApi* | [**youtube_comments_insert**](docs/CommentsApi.md#youtube_comments_insert) | **POST** /youtube/v3/comments | 
*CommentsApi* | [**youtube_comments_list**](docs/CommentsApi.md#youtube_comments_list) | **GET** /youtube/v3/comments | 
*CommentsApi* | [**youtube_comments_mark_as_spam**](docs/CommentsApi.md#youtube_comments_mark_as_spam) | **POST** /youtube/v3/comments/markAsSpam | 
*CommentsApi* | [**youtube_comments_set_moderation_status**](docs/CommentsApi.md#youtube_comments_set_moderation_status) | **POST** /youtube/v3/comments/setModerationStatus | 
*CommentsApi* | [**youtube_comments_update**](docs/CommentsApi.md#youtube_comments_update) | **PUT** /youtube/v3/comments | 
*I18nLanguagesApi* | [**youtube_i18n_languages_list**](docs/I18nLanguagesApi.md#youtube_i18n_languages_list) | **GET** /youtube/v3/i18nLanguages | 
*I18nRegionsApi* | [**youtube_i18n_regions_list**](docs/I18nRegionsApi.md#youtube_i18n_regions_list) | **GET** /youtube/v3/i18nRegions | 
*LiveBroadcastsApi* | [**youtube_live_broadcasts_bind**](docs/LiveBroadcastsApi.md#youtube_live_broadcasts_bind) | **POST** /youtube/v3/liveBroadcasts/bind | 
*LiveBroadcastsApi* | [**youtube_live_broadcasts_delete**](docs/LiveBroadcastsApi.md#youtube_live_broadcasts_delete) | **DELETE** /youtube/v3/liveBroadcasts | 
*LiveBroadcastsApi* | [**youtube_live_broadcasts_insert**](docs/LiveBroadcastsApi.md#youtube_live_broadcasts_insert) | **POST** /youtube/v3/liveBroadcasts | 
*LiveBroadcastsApi* | [**youtube_live_broadcasts_insert_cuepoint**](docs/LiveBroadcastsApi.md#youtube_live_broadcasts_insert_cuepoint) | **POST** /youtube/v3/liveBroadcasts/cuepoint | 
*LiveBroadcastsApi* | [**youtube_live_broadcasts_list**](docs/LiveBroadcastsApi.md#youtube_live_broadcasts_list) | **GET** /youtube/v3/liveBroadcasts | 
*LiveBroadcastsApi* | [**youtube_live_broadcasts_transition**](docs/LiveBroadcastsApi.md#youtube_live_broadcasts_transition) | **POST** /youtube/v3/liveBroadcasts/transition | 
*LiveBroadcastsApi* | [**youtube_live_broadcasts_update**](docs/LiveBroadcastsApi.md#youtube_live_broadcasts_update) | **PUT** /youtube/v3/liveBroadcasts | 
*LiveChatBansApi* | [**youtube_live_chat_bans_delete**](docs/LiveChatBansApi.md#youtube_live_chat_bans_delete) | **DELETE** /youtube/v3/liveChat/bans | 
*LiveChatBansApi* | [**youtube_live_chat_bans_insert**](docs/LiveChatBansApi.md#youtube_live_chat_bans_insert) | **POST** /youtube/v3/liveChat/bans | 
*LiveChatMessagesApi* | [**youtube_live_chat_messages_delete**](docs/LiveChatMessagesApi.md#youtube_live_chat_messages_delete) | **DELETE** /youtube/v3/liveChat/messages | 
*LiveChatMessagesApi* | [**youtube_live_chat_messages_insert**](docs/LiveChatMessagesApi.md#youtube_live_chat_messages_insert) | **POST** /youtube/v3/liveChat/messages | 
*LiveChatMessagesApi* | [**youtube_live_chat_messages_list**](docs/LiveChatMessagesApi.md#youtube_live_chat_messages_list) | **GET** /youtube/v3/liveChat/messages | 
*LiveChatMessagesApi* | [**youtube_live_chat_messages_transition**](docs/LiveChatMessagesApi.md#youtube_live_chat_messages_transition) | **POST** /youtube/v3/liveChat/messages/transition | 
*LiveChatModeratorsApi* | [**youtube_live_chat_moderators_delete**](docs/LiveChatModeratorsApi.md#youtube_live_chat_moderators_delete) | **DELETE** /youtube/v3/liveChat/moderators | 
*LiveChatModeratorsApi* | [**youtube_live_chat_moderators_insert**](docs/LiveChatModeratorsApi.md#youtube_live_chat_moderators_insert) | **POST** /youtube/v3/liveChat/moderators | 
*LiveChatModeratorsApi* | [**youtube_live_chat_moderators_list**](docs/LiveChatModeratorsApi.md#youtube_live_chat_moderators_list) | **GET** /youtube/v3/liveChat/moderators | 
*LiveStreamsApi* | [**youtube_live_streams_delete**](docs/LiveStreamsApi.md#youtube_live_streams_delete) | **DELETE** /youtube/v3/liveStreams | 
*LiveStreamsApi* | [**youtube_live_streams_insert**](docs/LiveStreamsApi.md#youtube_live_streams_insert) | **POST** /youtube/v3/liveStreams | 
*LiveStreamsApi* | [**youtube_live_streams_list**](docs/LiveStreamsApi.md#youtube_live_streams_list) | **GET** /youtube/v3/liveStreams | 
*LiveStreamsApi* | [**youtube_live_streams_update**](docs/LiveStreamsApi.md#youtube_live_streams_update) | **PUT** /youtube/v3/liveStreams | 
*MembersApi* | [**youtube_members_list**](docs/MembersApi.md#youtube_members_list) | **GET** /youtube/v3/members | 
*MembershipsLevelsApi* | [**youtube_memberships_levels_list**](docs/MembershipsLevelsApi.md#youtube_memberships_levels_list) | **GET** /youtube/v3/membershipsLevels | 
*PlaylistImagesApi* | [**youtube_playlist_images_delete**](docs/PlaylistImagesApi.md#youtube_playlist_images_delete) | **DELETE** /youtube/v3/playlistImages | 
*PlaylistImagesApi* | [**youtube_playlist_images_insert**](docs/PlaylistImagesApi.md#youtube_playlist_images_insert) | **POST** /youtube/v3/playlistImages | 
*PlaylistImagesApi* | [**youtube_playlist_images_list**](docs/PlaylistImagesApi.md#youtube_playlist_images_list) | **GET** /youtube/v3/playlistImages | 
*PlaylistImagesApi* | [**youtube_playlist_images_update**](docs/PlaylistImagesApi.md#youtube_playlist_images_update) | **PUT** /youtube/v3/playlistImages | 
*PlaylistItemsApi* | [**youtube_playlist_items_delete**](docs/PlaylistItemsApi.md#youtube_playlist_items_delete) | **DELETE** /youtube/v3/playlistItems | 
*PlaylistItemsApi* | [**youtube_playlist_items_insert**](docs/PlaylistItemsApi.md#youtube_playlist_items_insert) | **POST** /youtube/v3/playlistItems | 
*PlaylistItemsApi* | [**youtube_playlist_items_list**](docs/PlaylistItemsApi.md#youtube_playlist_items_list) | **GET** /youtube/v3/playlistItems | 
*PlaylistItemsApi* | [**youtube_playlist_items_update**](docs/PlaylistItemsApi.md#youtube_playlist_items_update) | **PUT** /youtube/v3/playlistItems | 
*PlaylistsApi* | [**youtube_playlists_delete**](docs/PlaylistsApi.md#youtube_playlists_delete) | **DELETE** /youtube/v3/playlists | 
*PlaylistsApi* | [**youtube_playlists_insert**](docs/PlaylistsApi.md#youtube_playlists_insert) | **POST** /youtube/v3/playlists | 
*PlaylistsApi* | [**youtube_playlists_list**](docs/PlaylistsApi.md#youtube_playlists_list) | **GET** /youtube/v3/playlists | 
*PlaylistsApi* | [**youtube_playlists_update**](docs/PlaylistsApi.md#youtube_playlists_update) | **PUT** /youtube/v3/playlists | 
*SearchApi* | [**youtube_search_list**](docs/SearchApi.md#youtube_search_list) | **GET** /youtube/v3/search | 
*SubscriptionsApi* | [**youtube_subscriptions_delete**](docs/SubscriptionsApi.md#youtube_subscriptions_delete) | **DELETE** /youtube/v3/subscriptions | 
*SubscriptionsApi* | [**youtube_subscriptions_insert**](docs/SubscriptionsApi.md#youtube_subscriptions_insert) | **POST** /youtube/v3/subscriptions | 
*SubscriptionsApi* | [**youtube_subscriptions_list**](docs/SubscriptionsApi.md#youtube_subscriptions_list) | **GET** /youtube/v3/subscriptions | 
*SuperChatEventsApi* | [**youtube_super_chat_events_list**](docs/SuperChatEventsApi.md#youtube_super_chat_events_list) | **GET** /youtube/v3/superChatEvents | 
*TestsApi* | [**youtube_tests_insert**](docs/TestsApi.md#youtube_tests_insert) | **POST** /youtube/v3/tests | 
*ThirdPartyLinksApi* | [**youtube_third_party_links_delete**](docs/ThirdPartyLinksApi.md#youtube_third_party_links_delete) | **DELETE** /youtube/v3/thirdPartyLinks | 
*ThirdPartyLinksApi* | [**youtube_third_party_links_insert**](docs/ThirdPartyLinksApi.md#youtube_third_party_links_insert) | **POST** /youtube/v3/thirdPartyLinks | 
*ThirdPartyLinksApi* | [**youtube_third_party_links_list**](docs/ThirdPartyLinksApi.md#youtube_third_party_links_list) | **GET** /youtube/v3/thirdPartyLinks | 
*ThirdPartyLinksApi* | [**youtube_third_party_links_update**](docs/ThirdPartyLinksApi.md#youtube_third_party_links_update) | **PUT** /youtube/v3/thirdPartyLinks | 
*ThumbnailsApi* | [**youtube_thumbnails_set**](docs/ThumbnailsApi.md#youtube_thumbnails_set) | **POST** /youtube/v3/thumbnails/set | 
*VideoAbuseReportReasonsApi* | [**youtube_video_abuse_report_reasons_list**](docs/VideoAbuseReportReasonsApi.md#youtube_video_abuse_report_reasons_list) | **GET** /youtube/v3/videoAbuseReportReasons | 
*VideoCategoriesApi* | [**youtube_video_categories_list**](docs/VideoCategoriesApi.md#youtube_video_categories_list) | **GET** /youtube/v3/videoCategories | 
*VideoTrainabilityApi* | [**youtube_video_trainability_get**](docs/VideoTrainabilityApi.md#youtube_video_trainability_get) | **GET** /youtube/v3/videoTrainability | 
*VideosApi* | [**youtube_videos_delete**](docs/VideosApi.md#youtube_videos_delete) | **DELETE** /youtube/v3/videos | 
*VideosApi* | [**youtube_videos_get_rating**](docs/VideosApi.md#youtube_videos_get_rating) | **GET** /youtube/v3/videos/getRating | 
*VideosApi* | [**youtube_videos_insert**](docs/VideosApi.md#youtube_videos_insert) | **POST** /youtube/v3/videos | 
*VideosApi* | [**youtube_videos_list**](docs/VideosApi.md#youtube_videos_list) | **GET** /youtube/v3/videos | 
*VideosApi* | [**youtube_videos_rate**](docs/VideosApi.md#youtube_videos_rate) | **POST** /youtube/v3/videos/rate | 
*VideosApi* | [**youtube_videos_report_abuse**](docs/VideosApi.md#youtube_videos_report_abuse) | **POST** /youtube/v3/videos/reportAbuse | 
*VideosApi* | [**youtube_videos_update**](docs/VideosApi.md#youtube_videos_update) | **PUT** /youtube/v3/videos | 
*WatermarksApi* | [**youtube_watermarks_set**](docs/WatermarksApi.md#youtube_watermarks_set) | **POST** /youtube/v3/watermarks/set | 
*WatermarksApi* | [**youtube_watermarks_unset**](docs/WatermarksApi.md#youtube_watermarks_unset) | **POST** /youtube/v3/watermarks/unset | 
*YoutubeApi* | [**youtube_youtube_v3_update_comment_threads**](docs/YoutubeApi.md#youtube_youtube_v3_update_comment_threads) | **PUT** /youtube/v3/commentThreads | 


## Documentation For Models

 - [AbuseReport](docs/AbuseReport.md)
 - [AbuseType](docs/AbuseType.md)
 - [AccessPolicy](docs/AccessPolicy.md)
 - [Activity](docs/Activity.md)
 - [ActivityContentDetails](docs/ActivityContentDetails.md)
 - [ActivityContentDetailsBulletin](docs/ActivityContentDetailsBulletin.md)
 - [ActivityContentDetailsChannelItem](docs/ActivityContentDetailsChannelItem.md)
 - [ActivityContentDetailsComment](docs/ActivityContentDetailsComment.md)
 - [ActivityContentDetailsFavorite](docs/ActivityContentDetailsFavorite.md)
 - [ActivityContentDetailsLike](docs/ActivityContentDetailsLike.md)
 - [ActivityContentDetailsPlaylistItem](docs/ActivityContentDetailsPlaylistItem.md)
 - [ActivityContentDetailsPromotedItem](docs/ActivityContentDetailsPromotedItem.md)
 - [ActivityContentDetailsRecommendation](docs/ActivityContentDetailsRecommendation.md)
 - [ActivityContentDetailsSocial](docs/ActivityContentDetailsSocial.md)
 - [ActivityContentDetailsSubscription](docs/ActivityContentDetailsSubscription.md)
 - [ActivityContentDetailsUpload](docs/ActivityContentDetailsUpload.md)
 - [ActivityListResponse](docs/ActivityListResponse.md)
 - [ActivitySnippet](docs/ActivitySnippet.md)
 - [Caption](docs/Caption.md)
 - [CaptionListResponse](docs/CaptionListResponse.md)
 - [CaptionSnippet](docs/CaptionSnippet.md)
 - [CdnSettings](docs/CdnSettings.md)
 - [Channel](docs/Channel.md)
 - [ChannelAuditDetails](docs/ChannelAuditDetails.md)
 - [ChannelBannerResource](docs/ChannelBannerResource.md)
 - [ChannelBrandingSettings](docs/ChannelBrandingSettings.md)
 - [ChannelContentDetails](docs/ChannelContentDetails.md)
 - [ChannelContentDetailsRelatedPlaylists](docs/ChannelContentDetailsRelatedPlaylists.md)
 - [ChannelContentOwnerDetails](docs/ChannelContentOwnerDetails.md)
 - [ChannelConversionPing](docs/ChannelConversionPing.md)
 - [ChannelConversionPings](docs/ChannelConversionPings.md)
 - [ChannelListResponse](docs/ChannelListResponse.md)
 - [ChannelLocalization](docs/ChannelLocalization.md)
 - [ChannelProfileDetails](docs/ChannelProfileDetails.md)
 - [ChannelSection](docs/ChannelSection.md)
 - [ChannelSectionContentDetails](docs/ChannelSectionContentDetails.md)
 - [ChannelSectionListResponse](docs/ChannelSectionListResponse.md)
 - [ChannelSectionLocalization](docs/ChannelSectionLocalization.md)
 - [ChannelSectionSnippet](docs/ChannelSectionSnippet.md)
 - [ChannelSectionTargeting](docs/ChannelSectionTargeting.md)
 - [ChannelSettings](docs/ChannelSettings.md)
 - [ChannelSnippet](docs/ChannelSnippet.md)
 - [ChannelStatistics](docs/ChannelStatistics.md)
 - [ChannelStatus](docs/ChannelStatus.md)
 - [ChannelToStoreLinkDetails](docs/ChannelToStoreLinkDetails.md)
 - [ChannelToStoreLinkDetailsBillingDetails](docs/ChannelToStoreLinkDetailsBillingDetails.md)
 - [ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails](docs/ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails.md)
 - [ChannelTopicDetails](docs/ChannelTopicDetails.md)
 - [Comment](docs/Comment.md)
 - [CommentListResponse](docs/CommentListResponse.md)
 - [CommentSnippet](docs/CommentSnippet.md)
 - [CommentSnippetAuthorChannelId](docs/CommentSnippetAuthorChannelId.md)
 - [CommentThread](docs/CommentThread.md)
 - [CommentThreadListResponse](docs/CommentThreadListResponse.md)
 - [CommentThreadReplies](docs/CommentThreadReplies.md)
 - [CommentThreadSnippet](docs/CommentThreadSnippet.md)
 - [ContentRating](docs/ContentRating.md)
 - [Cuepoint](docs/Cuepoint.md)
 - [CuepointSchedule](docs/CuepointSchedule.md)
 - [Entity](docs/Entity.md)
 - [GeoPoint](docs/GeoPoint.md)
 - [I18nLanguage](docs/I18nLanguage.md)
 - [I18nLanguageListResponse](docs/I18nLanguageListResponse.md)
 - [I18nLanguageSnippet](docs/I18nLanguageSnippet.md)
 - [I18nRegion](docs/I18nRegion.md)
 - [I18nRegionListResponse](docs/I18nRegionListResponse.md)
 - [I18nRegionSnippet](docs/I18nRegionSnippet.md)
 - [ImageSettings](docs/ImageSettings.md)
 - [IngestionInfo](docs/IngestionInfo.md)
 - [InvideoBranding](docs/InvideoBranding.md)
 - [InvideoPosition](docs/InvideoPosition.md)
 - [InvideoTiming](docs/InvideoTiming.md)
 - [LanguageTag](docs/LanguageTag.md)
 - [LevelDetails](docs/LevelDetails.md)
 - [LiveBroadcast](docs/LiveBroadcast.md)
 - [LiveBroadcastContentDetails](docs/LiveBroadcastContentDetails.md)
 - [LiveBroadcastListResponse](docs/LiveBroadcastListResponse.md)
 - [LiveBroadcastMonetizationDetails](docs/LiveBroadcastMonetizationDetails.md)
 - [LiveBroadcastSnippet](docs/LiveBroadcastSnippet.md)
 - [LiveBroadcastStatistics](docs/LiveBroadcastStatistics.md)
 - [LiveBroadcastStatus](docs/LiveBroadcastStatus.md)
 - [LiveChatBan](docs/LiveChatBan.md)
 - [LiveChatBanSnippet](docs/LiveChatBanSnippet.md)
 - [LiveChatFanFundingEventDetails](docs/LiveChatFanFundingEventDetails.md)
 - [LiveChatGiftMembershipReceivedDetails](docs/LiveChatGiftMembershipReceivedDetails.md)
 - [LiveChatMemberMilestoneChatDetails](docs/LiveChatMemberMilestoneChatDetails.md)
 - [LiveChatMembershipGiftingDetails](docs/LiveChatMembershipGiftingDetails.md)
 - [LiveChatMessage](docs/LiveChatMessage.md)
 - [LiveChatMessageAuthorDetails](docs/LiveChatMessageAuthorDetails.md)
 - [LiveChatMessageDeletedDetails](docs/LiveChatMessageDeletedDetails.md)
 - [LiveChatMessageListResponse](docs/LiveChatMessageListResponse.md)
 - [LiveChatMessageRetractedDetails](docs/LiveChatMessageRetractedDetails.md)
 - [LiveChatMessageSnippet](docs/LiveChatMessageSnippet.md)
 - [LiveChatModerator](docs/LiveChatModerator.md)
 - [LiveChatModeratorListResponse](docs/LiveChatModeratorListResponse.md)
 - [LiveChatModeratorSnippet](docs/LiveChatModeratorSnippet.md)
 - [LiveChatNewSponsorDetails](docs/LiveChatNewSponsorDetails.md)
 - [LiveChatPollDetails](docs/LiveChatPollDetails.md)
 - [LiveChatPollDetailsPollMetadata](docs/LiveChatPollDetailsPollMetadata.md)
 - [LiveChatPollDetailsPollMetadataPollOption](docs/LiveChatPollDetailsPollMetadataPollOption.md)
 - [LiveChatSuperChatDetails](docs/LiveChatSuperChatDetails.md)
 - [LiveChatSuperStickerDetails](docs/LiveChatSuperStickerDetails.md)
 - [LiveChatTextMessageDetails](docs/LiveChatTextMessageDetails.md)
 - [LiveChatUserBannedMessageDetails](docs/LiveChatUserBannedMessageDetails.md)
 - [LiveStream](docs/LiveStream.md)
 - [LiveStreamConfigurationIssue](docs/LiveStreamConfigurationIssue.md)
 - [LiveStreamContentDetails](docs/LiveStreamContentDetails.md)
 - [LiveStreamHealthStatus](docs/LiveStreamHealthStatus.md)
 - [LiveStreamListResponse](docs/LiveStreamListResponse.md)
 - [LiveStreamSnippet](docs/LiveStreamSnippet.md)
 - [LiveStreamStatus](docs/LiveStreamStatus.md)
 - [LocalizedProperty](docs/LocalizedProperty.md)
 - [LocalizedString](docs/LocalizedString.md)
 - [Member](docs/Member.md)
 - [MemberListResponse](docs/MemberListResponse.md)
 - [MemberSnippet](docs/MemberSnippet.md)
 - [MembershipsDetails](docs/MembershipsDetails.md)
 - [MembershipsDuration](docs/MembershipsDuration.md)
 - [MembershipsDurationAtLevel](docs/MembershipsDurationAtLevel.md)
 - [MembershipsLevel](docs/MembershipsLevel.md)
 - [MembershipsLevelListResponse](docs/MembershipsLevelListResponse.md)
 - [MembershipsLevelSnippet](docs/MembershipsLevelSnippet.md)
 - [MonitorStreamInfo](docs/MonitorStreamInfo.md)
 - [PageInfo](docs/PageInfo.md)
 - [Playlist](docs/Playlist.md)
 - [PlaylistContentDetails](docs/PlaylistContentDetails.md)
 - [PlaylistImage](docs/PlaylistImage.md)
 - [PlaylistImageListResponse](docs/PlaylistImageListResponse.md)
 - [PlaylistImageSnippet](docs/PlaylistImageSnippet.md)
 - [PlaylistItem](docs/PlaylistItem.md)
 - [PlaylistItemContentDetails](docs/PlaylistItemContentDetails.md)
 - [PlaylistItemListResponse](docs/PlaylistItemListResponse.md)
 - [PlaylistItemSnippet](docs/PlaylistItemSnippet.md)
 - [PlaylistItemStatus](docs/PlaylistItemStatus.md)
 - [PlaylistListResponse](docs/PlaylistListResponse.md)
 - [PlaylistLocalization](docs/PlaylistLocalization.md)
 - [PlaylistPlayer](docs/PlaylistPlayer.md)
 - [PlaylistSnippet](docs/PlaylistSnippet.md)
 - [PlaylistStatus](docs/PlaylistStatus.md)
 - [PropertyValue](docs/PropertyValue.md)
 - [RelatedEntity](docs/RelatedEntity.md)
 - [ResourceId](docs/ResourceId.md)
 - [SearchListResponse](docs/SearchListResponse.md)
 - [SearchResult](docs/SearchResult.md)
 - [SearchResultSnippet](docs/SearchResultSnippet.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionContentDetails](docs/SubscriptionContentDetails.md)
 - [SubscriptionListResponse](docs/SubscriptionListResponse.md)
 - [SubscriptionSnippet](docs/SubscriptionSnippet.md)
 - [SubscriptionSubscriberSnippet](docs/SubscriptionSubscriberSnippet.md)
 - [SuperChatEvent](docs/SuperChatEvent.md)
 - [SuperChatEventListResponse](docs/SuperChatEventListResponse.md)
 - [SuperChatEventSnippet](docs/SuperChatEventSnippet.md)
 - [SuperStickerMetadata](docs/SuperStickerMetadata.md)
 - [TestItem](docs/TestItem.md)
 - [ThirdPartyLink](docs/ThirdPartyLink.md)
 - [ThirdPartyLinkListResponse](docs/ThirdPartyLinkListResponse.md)
 - [ThirdPartyLinkSnippet](docs/ThirdPartyLinkSnippet.md)
 - [ThirdPartyLinkStatus](docs/ThirdPartyLinkStatus.md)
 - [Thumbnail](docs/Thumbnail.md)
 - [ThumbnailDetails](docs/ThumbnailDetails.md)
 - [ThumbnailSetResponse](docs/ThumbnailSetResponse.md)
 - [Video](docs/Video.md)
 - [VideoAbuseReport](docs/VideoAbuseReport.md)
 - [VideoAbuseReportReason](docs/VideoAbuseReportReason.md)
 - [VideoAbuseReportReasonListResponse](docs/VideoAbuseReportReasonListResponse.md)
 - [VideoAbuseReportReasonSnippet](docs/VideoAbuseReportReasonSnippet.md)
 - [VideoAbuseReportSecondaryReason](docs/VideoAbuseReportSecondaryReason.md)
 - [VideoAgeGating](docs/VideoAgeGating.md)
 - [VideoCategory](docs/VideoCategory.md)
 - [VideoCategoryListResponse](docs/VideoCategoryListResponse.md)
 - [VideoCategorySnippet](docs/VideoCategorySnippet.md)
 - [VideoContentDetails](docs/VideoContentDetails.md)
 - [VideoContentDetailsRegionRestriction](docs/VideoContentDetailsRegionRestriction.md)
 - [VideoFileDetails](docs/VideoFileDetails.md)
 - [VideoFileDetailsAudioStream](docs/VideoFileDetailsAudioStream.md)
 - [VideoFileDetailsVideoStream](docs/VideoFileDetailsVideoStream.md)
 - [VideoGetRatingResponse](docs/VideoGetRatingResponse.md)
 - [VideoListResponse](docs/VideoListResponse.md)
 - [VideoLiveStreamingDetails](docs/VideoLiveStreamingDetails.md)
 - [VideoLocalization](docs/VideoLocalization.md)
 - [VideoMonetizationDetails](docs/VideoMonetizationDetails.md)
 - [VideoPaidProductPlacementDetails](docs/VideoPaidProductPlacementDetails.md)
 - [VideoPlayer](docs/VideoPlayer.md)
 - [VideoProcessingDetails](docs/VideoProcessingDetails.md)
 - [VideoProcessingDetailsProcessingProgress](docs/VideoProcessingDetailsProcessingProgress.md)
 - [VideoRating](docs/VideoRating.md)
 - [VideoRecordingDetails](docs/VideoRecordingDetails.md)
 - [VideoSnippet](docs/VideoSnippet.md)
 - [VideoStatistics](docs/VideoStatistics.md)
 - [VideoStatus](docs/VideoStatus.md)
 - [VideoSuggestions](docs/VideoSuggestions.md)
 - [VideoSuggestionsTagSuggestion](docs/VideoSuggestionsTagSuggestion.md)
 - [VideoTopicDetails](docs/VideoTopicDetails.md)
 - [VideoTrainability](docs/VideoTrainability.md)
 - [WatchSettings](docs/WatchSettings.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="Oauth2"></a>
### Oauth2

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://accounts.google.com/o/oauth2/auth
- **Scopes**: 
 - **https://www.googleapis.com/auth/youtube**: Manage your YouTube account
 - **https://www.googleapis.com/auth/youtube.channel-memberships.creator**: See a list of your current active channel members, their current level, and when they became a member
 - **https://www.googleapis.com/auth/youtube.force-ssl**: See, edit, and permanently delete your YouTube videos, ratings, comments and captions
 - **https://www.googleapis.com/auth/youtube.readonly**: View your YouTube account
 - **https://www.googleapis.com/auth/youtube.upload**: Manage your YouTube videos
 - **https://www.googleapis.com/auth/youtubepartner**: View and manage your assets and associated content on YouTube
 - **https://www.googleapis.com/auth/youtubepartner-channel-audit**: View private information of your YouTube channel relevant during the audit process with a YouTube partner

<a id="Oauth2c"></a>
### Oauth2c

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://accounts.google.com/o/oauth2/auth
- **Scopes**: 
 - **https://www.googleapis.com/auth/youtube**: Manage your YouTube account
 - **https://www.googleapis.com/auth/youtube.channel-memberships.creator**: See a list of your current active channel members, their current level, and when they became a member
 - **https://www.googleapis.com/auth/youtube.force-ssl**: See, edit, and permanently delete your YouTube videos, ratings, comments and captions
 - **https://www.googleapis.com/auth/youtube.readonly**: View your YouTube account
 - **https://www.googleapis.com/auth/youtube.upload**: Manage your YouTube videos
 - **https://www.googleapis.com/auth/youtubepartner**: View and manage your assets and associated content on YouTube
 - **https://www.googleapis.com/auth/youtubepartner-channel-audit**: View private information of your YouTube channel relevant during the audit process with a YouTube partner


## Author




